IKFA(y, x, nFact = 5, IsPoly = FALSE, IsRot = TRUE,
ccoef = 1:nFact, check.data=TRUE, lean=FALSE, ...)
IKFA.fit(y, x, nFact = 5, IsPoly = FALSE, IsRot = TRUE,
ccoef = 1:nFact, lean=FALSE)
## S3 method for class 'IKFA':
predict(object, newdata=NULL, sse=FALSE, nboot=100,
match.data=TRUE, verbose=TRUE, \dots)
communality(object, y)
## S3 method for class 'IKFA':
crossval(object, cv.method="loo", verbose=TRUE, ngroups=10,
nboot=100, h.cutoff=0, h.dist=NULL, \dots)
## S3 method for class 'IKFA':
performance(object, \dots)
## S3 method for class 'IKFA':
rand.t.test(object, n.perm=999, \dots)
## S3 method for class 'IKFA':
screeplot(x, rand.test=TRUE, \dots)
## S3 method for class 'IKFA':
print(x, \dots)
## S3 method for class 'IKFA':
summary(object, full=FALSE, \dots)
## S3 method for class 'IKFA':
plot(x, resid=FALSE, xval=FALSE, nFact=max(x$ccoef),
xlab="", ylab="", ylim=NULL, xlim=NULL, add.ref=TRUE,
add.smooth=FALSE, ...)
## S3 method for class 'IKFA':
residuals(object, cv=FALSE, \dots)
## S3 method for class 'IKFA':
coef(object, \dots)
## S3 method for class 'IKFA':
fitted(object, \dots)wa.FALSE if you are sure the column names match exactly.plot.wa.h.cutoff from each test sample will be used.IKFA returns an object of class IKFA with the following named elements:crossval also returns an object of class IKFA and adds the following named elements:predict is called with newdata=NULL it returns the fitted values of the original model, otherwise it returns a list with the following named elements:newdata.performance returns a matrix of performance statistics for the IKFA model. See performance, for a description of the summary.
Function rand.t.test returns a matrix of performance statistics together with columns indicating the p-value and percentage change in RMSE with each higher component (see van der Veot (1994) for details).IKFA performs Imbrie and Kipp Factor Analysis, a form of Principal Components Regrssion (Imbrie & Kipp 1971).
Function predict predicts values of the environemntal variable for newdata or returns the fitted (predicted) values from the original modern dataset if newdata is NULL. Variables are matched between training and newdata by column name (if match.data is TRUE). Use compare.datasets to assess conformity of two species datasets and identify possible no-analogue samples.
IKFA has methods fitted and rediduals that return the fitted values (estimates) and residuals for the training set, performance, which returns summary performance statistics (see below), coef which returns the species coefficients, and print and summary to summarise the output. IKFA also has a plot method that produces scatter plots of predicted vs observed measurements for the training set.
Function rand.t.test performs a randomisation t-test to test the significance of the cross-validated components after van der Voet (1994).
Function screeplot displays the RMSE of prediction for the training set as a function of the number of factors and is useful for estimating the optimal number for use in prediction. By default screeplot will also carry out a randomisation t-test and add a line to scree plot indicating percentage change in RMSE with each component annotate with the p-value from the randomisation test.WA, MAT, performance, and compare.datasets for diagnostics.data(IK)
spec <- IK$spec
SumSST <- IK$env$SumSST
core <- IK$core
fit <- IKFA(spec, SumSST)
fit
# cross-validate model
fit.cv <- crossval(fit, cv.method="lgo")
# How many components to use?
screeplot(fit.cv)
#predict the core
pred <- predict(fit, core, npls=2)
#plot predictions - depths are in rownames
depth <- as.numeric(rownames(core))
plot(depth, pred$fit[, 2], type="b")
# fit using only factors 1, 2, 4, & 5
# and using polynomial terms
# as Imbrie & Kipp (1971)
fit2 <- IKFA(spec, SumSST, ccoef=c(1, 2, 4, 5), IsPoly=TRUE)
fit2.cv <- crossval(fit2, cv.method="lgo")
screeplot(fit2.cv)
# predictions with sample specific errors
# takes approximately 1 minute to run
pred <- predict(fit, core, sse=TRUE, nboot=1000)
predRun the code above in your browser using DataLab