spec diatom relative abundances, depths associated sediment core depths and 210Pb ages. Column names in RLGH$spec are short, 6-character alphanumeric codes for each diatom taxon. RLGH$names contains the full names for each taxon, in the correct order). Note that some rare and low abundance taxa have been removed so the percentages do not sum to 100.data(RLGH)data(RLGH)
names(RLGH$spec)
names(RLGH$depths)Run the code above in your browser using DataLab