strat.plot.simple plots all or a subset of variables in a data frame (y) against a single secondary variable (x). The function is appropriate for plotting stratigraphic data, with the x-variable is plotted on the y-axis and variables in y arrayed across the page. The function is primarily intended to visualise the effect of smoothing by plotting the original data with the interpolated or smoothed version superimposed.
The number of rows and columns in the plot may be controlled using the layout argument passed to link{xyplot}. For example layout=c(10,1) will produce a plot with 1 row and 10 columns.
By default, the x-axis has the same scale for all variables. To allow independent x-scales for each variable include the additional argument: scales=list(x="free")).
The function uses lattice to produce the plots so if you call it from a loop or using source you will need to wrap it in a print or plot statement.