Usage
MR(y, x, check.data=TRUE, lean=FALSE, ...)
MR.fit(y, x, lean=FALSE)
## S3 method for class 'MR':
predict(object, newdata=NULL, sse=FALSE, nboot=100,
match.data=TRUE, verbose=TRUE, \dots)
## S3 method for class 'MR':
crossval(object, cv.method="loo", verbose=TRUE, ngroups=10,
nboot=100, h.cutoff=0, h.dist=NULL, \dots)
## S3 method for class 'MR':
performance(object, \dots)
## S3 method for class 'MR':
print(x, \dots)
## S3 method for class 'MR':
summary(object, full=FALSE, \dots)
## S3 method for class 'MR':
plot(x, resid=FALSE, xval=FALSE, xlab="",
ylab="", ylim=NULL, xlim=NULL, add.ref=TRUE,
add.smooth=FALSE, \dots)
## S3 method for class 'MR':
residuals(object, cv=FALSE, \dots)
## S3 method for class 'MR':
coef(object, \dots)
## S3 method for class 'MR':
fitted(object, \dots)Arguments
y
a data frame or matrix of biological abundance data.
x, object
a vector of environmental values to be modelled or an object of class wa.
newdata
new biological data to be predicted.
check.data
logical to perform simple checks on the input data.
match.data
logical indicate the function will match two species datasets by their column names. You should only set this to FALSE if you are sure the column names match exactly.
lean
logical to exclude some output from the resulting models (used when cross-validating to speed calculations).
full
logical to show head and tail of output in summaries.
resid
logical to plot residuals instead of fitted values.
xval
logical to plot cross-validation estimates.
xlab, ylab, xlim, ylim
additional graphical arguments to plot.wa.
add.ref
add 1:1 line on plot.
add.smooth
add loess smooth to plot.
cv.method
cross-validation method, either "loo", "lgo" or "bootstrap".
verbose
logical to show feedback during cross-validaton.
nboot
number of bootstrap samples.
ngroups
number of groups in leave-group-out cross-validation, or a vector contain leave-out group menbership.
h.cutoff
cutoff for h-block cross-validation. Only training samples greater than h.cutoff from each test sample will be used.
h.dist
distance matrix for use in h-block cross-validation. Usually a matrix of geographical distances between samples.
sse
logical indicating that sample specific errors should be calculated.
cv
logical to indicate model or cross-validation residuals.