read.C2Model: Imports results from a C2 model into R
Description
Imports data from a C2 model saved in Excel format into R for further processing.Usage
read.C2Model(fName, force.read.xls=FALSE)
## S3 method for class 'C2':
print(x, \dots)
## S3 method for class 'C2':
summary(object, \dots)
Arguments
force.read.xls
logical to force function to use read.xls (see details).
x, object
object of class C2 produced by read.C2Model.
...
additional arguments to plot and print.
Value
- Returns a list with elements corresponding to the worksheets in the saved C2 model: these are named after the original worksheets under Windows but "Sheet1", "Sheet2", etc. on Linux and MacOS X.
source
Juggins. S. (2007) C2 Version 1.5 User guide. Software for ecological and palaeoecological data analysis and visualisation. Newcastle University, Newcastle upon Tyne, UK. 73pp.Details
Function to import data from a C2 model into R for further processing. C2 is a Windows program for the analysis and visualisation of palaeoecological data (Juggins (2007). On Windows read.C2Model uses the package RODBC to import data from the Excel spreadsheet whereas on Linux and MacOS X the function uses read.xls in the package gdata. Use the option force.read.xls=TRUE to force the function to use read.xls if you have 32/64 bit incompatibility problems with RODBC on Windows.Examples
Run this codepth <- system.file("example.datasets/C2_IK_Model.xls", package="rioja")
C2.IK <- read.C2Model(pth)
summary(C2.IK)
Run the code above in your browser using DataLab